@@ -10,5 +10,13 @@ from nano_duration.exceptions import (  # noqa  # isort:skip
 )  # noqa  # isort:skip
 from nano_duration.iso_duration import generate, parse  # noqa  # isort:skip
 from nano_duration.duration import Duration  # noqa  # isort:skip
+from nano_duration import calendar  # noqa  # isort:skip
 
-__all__ = ("parse", "generate", "IncorrectValue", "IncorrectPattern", "Duration")
+__all__ = (
+    "parse",
+    "generate",
+    "IncorrectValue",
+    "IncorrectPattern",
+    "Duration",
+    "calendar",
+)
